/***********************************************************************************
FILE NAME  	: cmt1.c

DESCRIPTION	: Demonstration of Compare Match Timer (CMT) module.
			  Sets up compare match timer(CMT) to toggle the LEDs on compare match.

OPERATION   : 1. Build this application and download it to the target. Press 'Reset Go'.
			  2. All LEDs will toggle their state when compare match occurs.
			     User may observe LEDs flashing at constant rate approximately 1 second.

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
16.08.2011 modified by syslab
***********************************************************************************/

/**********************************************************************************
User Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include "intrinsics.h"
/*	Following header file provides a structure to access on-chip I/O registers. */
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "syslab7086def.h"
/* Following header file provides prototype for the functions defined in this file.	*/
#include "cmt.h"
/*	Following header file provides vector locations for the interrupts. */
#include "inthandler.h"

#ifdef CMT_1
/**********************************************************************************
User Program Code
***********************************************************************************/

/**********************************************************************************
Function Name: 	CMT1_Init
Description:	Initialises cmt1 module.
Parameters: 	none
Return value: 	none
***********************************************************************************/
void CMT1_Init(void)
{
	/* Enable CMT module */
	STB.CR4.BIT._CMT = 0;

	/* Ensure timer is stopped before modifying settings */
	CMT.CMSTR.BIT.STR1 = 0;

	/* Configure CMT as follws
	   clock/64 mode (40MHz/512 = 12.8us/clock)
	   Enable CMI Interrupt 	*/
	CMT1.CMCSR.WORD = 0x0043;

	/* Set compare match value in the CMCOR register. */
	CMT1.CMCOR = 0x9896;

	/* Set the Interrupt Priority Level to 4 */
	INTC.IPRJ.BIT._CMT1 = 4;
}
/**********************************************************************************
End of function CMT1_Init
***********************************************************************************/
/**********************************************************************************
ISR Name: 		INT_CMT1_CMI1
Description:	Interrupt handler for CMT1 compare match.
Parameters: 	none
Return value: 	none
***********************************************************************************/
void INT_CMT1_CMI1(void)
{
	/* Toggle the pin states. */
	LED_PORT_DR ^= LED_BIT;

	/* Clear the interrupt flag	*/
	CMT1.CMCSR.BIT.CMF = 0;
}
/**********************************************************************************
End of ISR INT_CMT1_CMI1
***********************************************************************************/
#endif
/**********************************************************************************
End of file
***********************************************************************************/
