/****************************************************************
KPIT Cummins Infosystems Ltd, Pune, India. - 10-Mar-2003.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

*****************************************************************/

/***********************************************************************************
FILE NAME  	: hwinit.c

DESCRIPTION	: Sets up RSK hardware.

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
16.08.2011 modified by syslab
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include "intrinsics.h"

/***********************************************************************************
User Includes
***********************************************************************************/
/* Following header file provides a structure to access all of the device registers. */
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "syslab7086def.h"
/* Following header file provides function prototype for hardware setup function. */
//#include "hwsetup.h"


#ifdef __cplusplus
extern "C" {
#endif
extern void hw_initialise(void);
#ifdef __cplusplus
}
#endif

/***********************************************************************************
User Program Code Prototypes
***********************************************************************************/
/* These fuctions are private so their prototypes are defined locally */
static void ConfigureOperatingFrequency(void);
static void EnablePeripheralModules(void);
static void ConfigurePortPins(void);

/***********************************************************************************
User Program Code
***********************************************************************************/

/***********************************************************************************
Function Name: 	hw_initialise
Description:	Sets up hardware
Parameters:		none
Return value:	none
***********************************************************************************/
void hw_initialise(void)
{
	ConfigureOperatingFrequency();
	ConfigurePortPins();
//	EnablePeripheralModules();
	//ConfigureInterrupts();
}
/***********************************************************************************
End of function hw_initialise
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigureOperatingFrequency
Description:	Sets up operating speed
Parameters: 	none
Return value: 	none
***********************************************************************************/
void ConfigureOperatingFrequency(void)
{
	/* Setting FRQCR: IFC=80MHz, BFC & PFC = 40MHz, MIFC=80MHz, MPFC=40MHz */
	CPG.FRQCR.WORD = 0x0241;
}
/***********************************************************************************
End of function ConfigureOperatingFrequency
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigurePortPins
Description:	Configures port pins.
Parameters: 	none
Return value: 	none
***********************************************************************************/
void ConfigurePortPins(void)
{
/* Port pins default to inputs. To ensure safe initialisation set the pin states
before changing the data direction registers. This will avoid any unintentional
state changes on the external ports.
Many peripheral modules will override the setting of the port registers. Ensure
that the state is safe for external devices if the internal peripheral module is
disabled or powered down. */

/* Switch Port configuration */

	/* LED Port configuration (LED0 - LED3 as o/p. respectively)*/
//		PFC.PAIORH.BIT.B20 = 1;
//		PFC.PAIORH.BIT.B21 = 1;
//		PFC.PAIORH.BIT.B22 = 1;
//		PFC.PAIORH.BIT.B23 = 1;
		PFC.PBIORL.BIT.B0 = 1;
		PFC.PBIORL.BIT.B1 = 1;

	/* Sets the bits in the LED Port DR */
		LED_PORT_DR = LEDS_OFF;

	/* LCD Port configuration (set as o/p.)  DLCD4 - DLCD7,DLCDE, DLCDRS respectively */
//		PFC.PBIORL.BIT.B4 = 1;
//		PFC.PBIORL.BIT.B5 = 1;
//		PFC.PBIORL.BIT.B6 = 1;
//		PFC.PBIORL.BIT.B7 = 1;

//		PFC.PAIORH.BIT.B24 = 1;
//		PFC.PAIORH.BIT.B25 = 1;

	/* LCD data configuration */
//		PA.DR.BIT.B24 = SET_BIT_LOW;
//		PA.DR.BIT.B25 = SET_BIT_HIGH;
}
/***********************************************************************************
End of function ConfigurePortPins
***********************************************************************************/

/***********************************************************************************
Function Name: 	EnablePeripheralModules
Description:	Enables Peripheral Modules before use
Parameters: 	none
Return value: 	none
***********************************************************************************/
void EnablePeripheralModules(void)
{
	/* Enable SCI_0 module */
	STB.CR3.BIT._SCI0 = 0;
	/* Enable SCI_1 module */
	STB.CR3.BIT._SCI1 = 0;
}
/***********************************************************************************
End of function EnablePeripheralModules
***********************************************************************************/

/**********************************************************************************
End of file
***********************************************************************************/
